lck.config.FunkyConfigParser
============================

.. currentmodule:: lck.config

.. autoclass:: FunkyConfigParser

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FunkyConfigParser.__init__
      ~FunkyConfigParser.add_section
      ~FunkyConfigParser.defaults
      ~FunkyConfigParser.get
      ~FunkyConfigParser.getboolean
      ~FunkyConfigParser.getfloat
      ~FunkyConfigParser.getint
      ~FunkyConfigParser.getlist
      ~FunkyConfigParser.has_option
      ~FunkyConfigParser.has_section
      ~FunkyConfigParser.items
      ~FunkyConfigParser.options
      ~FunkyConfigParser.optionxform
      ~FunkyConfigParser.read
      ~FunkyConfigParser.readfp
      ~FunkyConfigParser.remove_option
      ~FunkyConfigParser.remove_section
      ~FunkyConfigParser.sections
      ~FunkyConfigParser.set
      ~FunkyConfigParser.write
   
   

   
   
   
